<!-- 导入数据组件 -->
<template>
  <div class="export-import-container">
    <el-button type="primary" plain @click="openDialog" icon="el-icon-upload2"
      >导入</el-button
    >
    <el-dialog
      :close-on-click-modal="false"
      title="导入"
      top="10vh"
      width="500px"
      appendToBody
      :visible.sync="dialogShow"
      @close="cancel"
    >
      <el-form ref="form" label-width="80px">
        <el-form-item label="默认模板 :">
          <el-button
            type="primary"
            icon="el-icon-download"
            @click="downloadTemp"
            :loading="downLoading"
            >模板下载</el-button
          >
        </el-form-item>

        <el-form-item label="文件导入 :">
          <el-row>
            <el-col :span="10">
              <el-upload
                style="display: inline-block"
                ref="upload"
                accept=".xlsx,.xls"
                :limit="1"
                :data="originAPIOptions.params"
                :auto-upload="false"
                :action="importUrl"
                :headers="uploadHeaders"
                :before-upload="beforeUpload"
                :on-exceed="onExceed"
                :on-error="handleUploadResult"
                :on-success="handleUploadResult"
              >
                <el-button
                  size="small"
                  type="primary"
                  plain
                  icon="el-icon-folder-opened"
                  >选择Excel文件</el-button
                >
              </el-upload>
            </el-col>
            <el-col :span="12">
              <el-button
                style="display: inline-block"
                type="primary"
                icon="el-icon-upload"
                @click="submitImport"
                element-loading-text="拼命导入中"
                v-loading.fullscreen.lock="uploading"
              >
                导 入
              </el-button>
            </el-col>
          </el-row>
        </el-form-item>
      </el-form>
      <span slot="footer" class="dialog-footer">
        <el-button @click="cancel">关 闭</el-button>
      </span>
    </el-dialog>
  </div>
</template>

<script>
import req from '@/request.js'
import portal from '@/api/portal'
export default {
  name: 'ImportData',
  props: {
    // 模板文件名称
    tempFiles: {
      type: String,
      default: '',
      required: true
    },
    originAPIOptions: {
      type: Object,
      default: () => {},
      required: true
    }
  },
  computed: {
    uploadHeaders: function(mapState) {
      return {
        Authorization: 'Bearer ' + this.$store.state.login.currentUser.token
      }
    },
    importUrl: function() {
      return window.context.portal + this.originAPIOptions.uploadApi
    }
  },
  data() {
    return {
      dialogShow: false,
      downLoading: false,
      uploading: false
    }
  },
  mounted() {},
  methods: {
    cancel() {
      this.$refs.upload.clearFiles()
      this.dialogShow = false
      this.downLoading = false
    },

    openDialog() {
      this.dialogShow = true
    },
    downloadTemp() {
      this.downLoading = true
      let params = {
        url: window.context.portal + this.originAPIOptions.downloadApi,
        method: 'GET',
        responseType: 'blob'
      }
      req.request(params).then(res => {
        const content = res.data
        const blob = new Blob([content])
        const fileName = `${this.tempFiles}.xls`
        const elink = document.createElement('a')
        elink.download = fileName
        elink.style.display = 'none'
        elink.href = URL.createObjectURL(blob)
        document.body.appendChild(elink)
        elink.click()
        URL.revokeObjectURL(elink.href) // 释放URL 对象
        document.body.removeChild(elink)
        this.downLoading = false
      })
    },
    beforeUpload(file) {
      if (!file.name.endsWith('.xlsx') && !file.name.endsWith('.xls')) {
        this.$message.warning('只能导入Excel文件!')
        return false
      }
      this.uploading = true
    },
    //导入
    onExceed(file) {
      this.$message.warning('只能选择一个Excel文件!')
    },
    handleUploadResult(response, file, fileList) {
      this.uploading = false
      if (response.state) {
        this.$message.success(response.message)
        this.dialogShow = false
        this.$emit('reload')
      } else {
        this.$message.error(response.message + '：' + response.value)
      }
    },
    submitImport() {
      if (
        !this.$refs.upload.uploadFiles ||
        this.$refs.upload.uploadFiles.length == 0
      ) {
        this.$message.warning('请选择要导入的数据文件!')
        return false
      }
      this.$refs.upload.submit()
    }
  }
}
</script>

<style lang="scss" scoped>
@import '../style.scss';
.export-import-container /deep/.el-form-item__content {
  margin-left: 80px !important;
}
</style>
